#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:           qubes-kernel-vm-support
Version:        4.1.15
Release:        1%{?dist}
Summary:        Qubes VM initramfs modules
Source0:        qubes-utils-%{version}.tar.gz

Group:          Qubes
Vendor:         Invisible Things Lab
License:        GPL v2 only
URL:            http://www.qubes-os.org

Requires:       dracut
BuildRequires:  make

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Fri Jun 18 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils.git

* Fri Jun 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 07ea7b2
- version 4.1.15

* Thu May 13 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 308d708
- version 4.1.14

* Wed May 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0209684
- Force exporting of loop devices

* Tue May 11 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 546e0c9
- Add do_unpack_ext to limit what can be unpacked

* Mon Apr 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 54afa23
- Use a flexable array member instead of an empty array

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c16c721
- kernel-vm-support: fix spec indentation

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a26b504
- kernel-vm-support: add make as BR

* Fri Feb 05 2021 Shawn Anastasio <shawn@anastas.io> - ac0e7bb
- Makefile: remove broken 32-bit host check

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 72458b4
- version 4.1.13

* Wed Jan 06 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 685d201
- Fix CI

* Tue Jan 05 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - a8ca815
- Mass replace: ‘/var/run’ → ‘/run’

* Tue Jan 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1eff32a
- archlinux: add makedepends on qubes-vm-xen

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - e872754
- Validate remote filename before displaying it

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 87ead86
- Modernize systemd unit files

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - cf009e8
- Meminfo writer comes before user logins

* Fri Dec 18 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - befbd65
- Fix some links to more modern versions

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a7e3632
- debian: update compat

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6154498
- debian: update control

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8289227
- tests: fix IncompleteReadError exception location

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4ceee75
- ci: add coverage

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 04aacff
- gitlab-ci: add custom jobs

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7160bc7
- Add .gitlab-ci.yml

* Fri Nov 13 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 53120a7
- version 4.1.12

* Thu Nov 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 01e69a7
- rpm,deb: /lib is a symlink to /usr/lib, move the files appropriately

* Thu Nov 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c5413af
- Set /dev/xen/* permissions early

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b124c71
- dracut: enable swap as early as possible

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dab2c31
- travis: fix build/install jobs

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 81d3430
- debian: don't fail package install on missing /var/lib/qubes

* Fri Oct 16 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a23aa0b
- dracut: remove useless use of basename

* Wed Aug 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cb27dff
- version 4.1.11

* Wed Aug 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0e1e8d4
- travis: restore 'language: python'

* Fri Aug 07 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3c00702
- Update travis

* Mon Jun 29 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 28c2d3e
- version 4.1.10

* Sun Jun 28 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aa1d86f
- debian: adjust dependencies for split python3-qubesimgconverter

* Sat Jun 20 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e1e4932
- version 4.1.9

* Sat Jun 20 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 51ea359
- debian: add python3-cairo dependency

* Sat Jun 20 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - adc121b
- debian: split python qubesimgconverter

* Fri Jun 19 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d8cd7df
- version 4.1.8

* Thu Jun 11 2020 null pointer exception <57326449+deathgrippin@users.noreply.github.com> - 1920032
- Fix typo

* Sun May 31 2020 Rusty Bird <rustybird@net-c.com> - 043793f
- imgconverter: make output reproducible by omitting timestamps

* Wed May 27 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7f864e8
- debian: drop python2 from dependencies

* Fri May 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 641ea6b
- version 4.1.7

* Fri May 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c707a18
- debian: bump libqubes-rpc-filecopy2 required version

* Fri May 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aba6ec6
- qrexec-lib/unpack: option to wait for free disk space

* Thu Apr 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1e583b9
- makefile: specify PYTHON at build stage too

* Wed Apr 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 20505a8
- version 4.1.6

* Sun Mar 29 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - a631e3b
- Image.get_from_stream_async(): fix large sizes

* Sun Mar 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 37248f5
- version 4.1.5

* Tue Mar 17 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 42236a8
- Image.get_through_dvm: support Python 3

* Tue Mar 17 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1113bf3
- version 4.1.4

